===============
The corner page
===============

PESummary prides itself on customisation and the
`customisable corner plot <https://pesummary.github.io/GW190412/html/IMRPhenomPv3HM_IMRPhenomPv3HM_Corner.html>`_
is one of its best features. One of the main disadvantages of a large
corner plot is navigation. If more than 10 parameters are passed, it becomes
very difficult to find correlations between specific parameters. This is solved
by PESummary by allowing the user to specify only the parameters that they are
interested in and only returning a corner plot for those specific parameters.
This custom corner plot can then be saved or changed to add more or less
parameters easily by the search or side bar.

.. note::
    The search bar must be empty if you choose to tick the options in the side
    bar

PESummary offers preselected `popular choices` which can be clicked. An example
video showing how this works is available below:

.. raw:: html

    <video width="700" height="500" controls>
        <source src="./examples/corner.mp4" type="video/mp4">
    Your browser does not support the video tag.
    </video>
